package com.goldenwater.slaj.stan.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.stan.mapper.BisStanReviRecMapper;
import com.goldenwater.slaj.stan.domain.BisStanReviRec;
import com.goldenwater.slaj.stan.service.IBisStanReviRecService;

@Service
public class BisStanReviRecServiceImpl implements IBisStanReviRecService {
    @Autowired
    private BisStanReviRecMapper bisStanReviRecMapper;

    @Override
    public BisStanReviRec selectBisStanReviRecByGuid(String guid) { return bisStanReviRecMapper.selectBisStanReviRecByGuid(guid); }
    @Override
    public List<BisStanReviRec> selectBisStanReviRecList(BisStanReviRec bisStanReviRec) { return bisStanReviRecMapper.selectBisStanReviRecList(bisStanReviRec); }
    @Override
    public int insertBisStanReviRec(BisStanReviRec bisStanReviRec) { return bisStanReviRecMapper.insertBisStanReviRec(bisStanReviRec); }
    @Override
    public int updateBisStanReviRec(BisStanReviRec bisStanReviRec) { return bisStanReviRecMapper.updateBisStanReviRec(bisStanReviRec); }
    @Override
    public int deleteBisStanReviRecByGuid(String guid) { return bisStanReviRecMapper.deleteBisStanReviRecByGuid(guid); }
    @Override
    public int deleteBisStanReviRecByGuids(String[] guids) { return bisStanReviRecMapper.deleteBisStanReviRecByGuids(guids); }
}
