package com.goldenwater.slaj.stan.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.stan.domain.BisStanReviRec;
import com.goldenwater.slaj.stan.service.IBisStanReviRecService;

@RestController
@RequestMapping("/stan/stanrevirec")
public class BisStanReviRecController extends BaseController {
    @Autowired
    private IBisStanReviRecService bisStanReviRecService;

    @GetMapping("/list")
    public TableDataInfo list(BisStanReviRec bisStanReviRec) { startPage(); List<BisStanReviRec> list = bisStanReviRecService.selectBisStanReviRecList(bisStanReviRec); return getDataTable(list); }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) { return AjaxResult.success(bisStanReviRecService.selectBisStanReviRecByGuid(guid)); }

    @PostMapping
    public AjaxResult add(@RequestBody BisStanReviRec bisStanReviRec) { return toAjax(bisStanReviRecService.insertBisStanReviRec(bisStanReviRec)); }

    @PutMapping
    public AjaxResult edit(@RequestBody BisStanReviRec bisStanReviRec) { return toAjax(bisStanReviRecService.updateBisStanReviRec(bisStanReviRec)); }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) { return toAjax(bisStanReviRecService.deleteBisStanReviRecByGuids(guids)); }

    @Log(title = "标准化评审记录管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('stan:stanrevirec:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BisStanReviRec bisStanReviRec) { List<BisStanReviRec> list = bisStanReviRecService.selectBisStanReviRecList(bisStanReviRec); ExcelUtil<BisStanReviRec> util = new ExcelUtil<BisStanReviRec>(BisStanReviRec.class); util.exportExcel(response, list, "标准化评审记录管理数据"); }
}
